@@ -28,12 +28,12 @@ along with pyscard; if not, write to the Free Software
 Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 """
 
-from sys import exc_info
-from threading import Thread, Event, enumerate
+from __future__ import print_function
+from threading import Thread, Event
 from time import sleep
+import traceback
 
 import smartcard.System
-from smartcard.Exceptions import ListReadersException
 from smartcard.Observer import Observer
 from smartcard.Observer import Observable
 from smartcard.Synchronization import *
@@ -49,12 +49,13 @@ class ReaderObserver(Observer):
     def __init__(self):
         pass
 
-    def update(self, observable, (addedreaders, removedreaders)):
+    def update(self, observable, handlers):
         """Called upon reader insertion/removal.
 
         observable:
-        addedreaders: list of added readers causing notification
-        removedreaders: list of removed readers causing notification
+        handlers:
+            addedreaders: list of added readers causing notification
+            removedreaders: list of removed readers causing notification
         """
         pass
 
@@ -105,8 +106,14 @@ class ReaderMonitor(Observable):
                     # avoid a deadlock; addObserver and notifyObservers called
                     # in the ReaderMonitoringThread run() method are
                     # synchronized
-                    import thread
-                    thread.start_new_thread(self.rmthread.start, ())
+                    try:
+                        # Python 3.x
+                        import _thread
+                        _thread.start_new_thread(self.rmthread.start, ())
+                    except:
+                        # Python 2.x
+                        import thread
+                        thread.start_new_thread(self.rmthread.start, ())
         else:
             observer.update(self, (self.rmthread.readers, []))
 
@@ -182,7 +189,9 @@ class ReaderMonitoringThread(Thread):
                 # wait every second on stopEvent
                 self.stopEvent.wait(self.period)
 
-            except Exception, e:
+            except Exception:
+                # FIXME Tighten the exceptions caught by this block
+                traceback.print_exc()
                 # Most likely raised during interpreter shutdown due
                 # to unclean exit which failed to remove all observers.
                 # To solve this, we set the stop event and pass the
@@ -194,8 +203,7 @@ class ReaderMonitoringThread(Thread):
         self.join()
 
 if __name__ == "__main__":
-    from smartcard.ReaderMonitoring import ReaderMonitor
-    print 'insert or remove readers in the next 20 seconds'
+    print('insert or remove readers in the next 20 seconds')
 
     # a simple reader observer that prints added/removed readers
     class printobserver(ReaderObserver):
@@ -203,9 +211,10 @@ if __name__ == "__main__":
         def __init__(self, obsindex):
             self.obsindex = obsindex
 
-        def update(self, observable, (addedreaders, removedreaders)):
-            print "%d - added:   " % self.obsindex, addedreaders
-            print "%d - removed: " % self.obsindex, removedreaders
+        def update(self, observable, handlers):
+            addedreaders, removedreaders = handlers
+            print("%d - added:   " % self.obsindex, addedreaders)
+            print("%d - removed: " % self.obsindex, removedreaders)
 
     class testthread(Thread):
 
