@@ -27,6 +27,7 @@ Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 """
 
 
+from __future__ import print_function
 import unittest
 import string
 
@@ -39,8 +40,8 @@ sys.path += ['..']
 try:
     from local_config import expectedATRs, expectedReaders
     from local_config import expectedReaderGroups, expectedATRinReader
-except:
-    print 'execute test suite first to generate the local_config.py file'
+except ImportError:
+    print('execute test suite first to generate the local_config.py file')
     sys.exit()
 
 
@@ -60,8 +61,8 @@ class testcase_CardType(unittest.TestCase):
             if [] != expectedATRinReader[str(reader)]:
                 connection = reader.createConnection()
                 connection.connect()
-                self.assertEquals(True, ct.matches(connection.getATR()))
-                self.assertEquals(
+                self.assertEqual(True, ct.matches(connection.getATR()))
+                self.assertEqual(
                     True, ct.matches(connection.getATR(), reader))
                 connection.disconnect()
 
@@ -73,8 +74,8 @@ class testcase_CardType(unittest.TestCase):
                 ct = ATRCardType(expectedATRinReader[str(reader)])
                 connection = reader.createConnection()
                 connection.connect()
-                self.assertEquals(True, ct.matches(connection.getATR()))
-                self.assertEquals(
+                self.assertEqual(True, ct.matches(connection.getATR()))
+                self.assertEqual(
                     True, ct.matches(connection.getATR(), reader))
                 connection.disconnect()
 
@@ -89,8 +90,8 @@ class testcase_CardType(unittest.TestCase):
                 ct = ATRCardType(atr)
                 connection = reader.createConnection()
                 connection.connect()
-                self.assertEquals(False, ct.matches(connection.getATR()))
-                self.assertEquals(
+                self.assertEqual(False, ct.matches(connection.getATR()))
+                self.assertEqual(
                     False, ct.matches(connection.getATR(), reader))
                 connection.disconnect()
 
@@ -99,7 +100,7 @@ class testcase_CardType(unittest.TestCase):
 
         for reader in readers():
             if [] != expectedATRinReader[str(reader)]:
-                mask = map(lambda x: 0xFF, expectedATRinReader[str(reader)])
+                mask = [0xFF for x in expectedATRinReader[str(reader)]]
                 # don't look to the last byte
                 mask[-1] = 0x00
                 ct = ATRCardType(expectedATRinReader[str(reader)], mask)
@@ -109,15 +110,15 @@ class testcase_CardType(unittest.TestCase):
                 connection.disconnect()
                 # change a bit in the last byte
                 atr[-1] = atr[-1] ^ 0xFF
-                self.assertEquals(True, ct.matches(atr))
-                self.assertEquals(True, ct.matches(atr, reader))
+                self.assertEqual(True, ct.matches(atr))
+                self.assertEqual(True, ct.matches(atr, reader))
 
     def testcase_ATRCardTypeWithMaskMismatch(self):
         """Test smartcard.ATRCardType with mask and mismatch."""
 
         for reader in readers():
             if [] != expectedATRinReader[str(reader)]:
-                mask = map(lambda x: 0xFF, expectedATRinReader[str(reader)])
+                mask = [0xFF for x in expectedATRinReader[str(reader)]]
                 # don't look to the last byte
                 mask[0] = mask[-1] = 0x00
                 ct = ATRCardType(expectedATRinReader[str(reader)], mask)
@@ -127,8 +128,8 @@ class testcase_CardType(unittest.TestCase):
                 connection.disconnect()
                 # change a bit in the :-2 byte
                 atr[-2] = atr[-2] ^ 0xFF
-                self.assertEquals(False, ct.matches(atr))
-                self.assertEquals(False, ct.matches(atr, reader))
+                self.assertEqual(False, ct.matches(atr))
+                self.assertEqual(False, ct.matches(atr, reader))
 
 
 def suite():
